from setuptools import setup, find_packages


setup(
    name="tyz",
    version="0.0.1",
    author="Yunzhou Tang",
    author_email="1209665265@qq.com",
    description="Learn to Pack Python Module",
    url="https://github.com/tyz-dev/tyz",
    packages=find_packages(),  # 自动识别包
)
